@@ -1,7 +1,6 @@
 spLM <- function(formula, data = parent.frame(), coords, knots, 
                  starting, tuning, priors, cov.model,
                  modified.pp=TRUE, amcmc, n.samples,
-                 ##get.beta=FALSE, start=1, end, thin=1,
                  verbose=TRUE, n.report=100, ...){
   
   ####################################################
@@ -317,30 +316,6 @@ spLM <- function(formula, data = parent.frame(), coords, knots,
   storage.mode(tau.sq.tuning) <- "double"
   storage.mode(nu.tuning) <- "double"
   
-  ####################################################
-  ##Recover beta (removed for now)
-  ####################################################
-  n.samples <- batch.length*n.batch
-  
-  ## if(missing(end)){end <- n.samples}
-  
-  ## if(!is.numeric(start) || start >= n.samples)
-  ##   stop("error: invalid start for recovery of beta")
-  ## if(!is.numeric(end) || end > n.samples) 
-  ##   stop("error: invalid end for recovery of beta")
-  ## if(!is.numeric(thin) || thin >= n.samples) 
-  ##   stop("error: invalid thin for recovery of beta")
-
-  ##identifies which samples should be used for recovery
-  r.indx <- rep(0,n.samples)
-  ## r.indx[seq(start, end, by=as.integer(thin))] <- 1
-
-  ##switch off for now
-  get.beta <- FALSE
-  
-  storage.mode(r.indx) <- "integer"
-  storage.mode(get.beta) <- "integer"
-  
   ####################################################
   ##Other stuff
   ####################################################
@@ -389,7 +364,6 @@ spLM <- function(formula, data = parent.frame(), coords, knots,
                  beta.prior, beta.Norm, sigma.sq.IG, tau.sq.IG, nu.Unif, phi.Unif,
                  phi.starting, sigma.sq.starting, tau.sq.starting, nu.starting,
                  phi.tuning, sigma.sq.tuning, tau.sq.tuning, nu.tuning,
-                 get.beta, r.indx,
                  nugget, cov.model, is.amcmc, n.batch, batch.length, accept.rate, verbose, n.report)   
   }
   
@@ -399,12 +373,7 @@ spLM <- function(formula, data = parent.frame(), coords, knots,
   if(is.pp){
     out$p.beta.samples <- mcmc(t(out$p.beta.samples))
     colnames(out$p.beta.samples) <- x.names
-  }## else{
-  ##   if(get.beta){
-  ##     out$p.beta.samples <- mcmc(t(out$p.beta.samples))
-  ##     colnames(out$p.beta.samples) <- x.names
-  ##   }
-  ## }
+  }
   
   out$p.theta.samples <- mcmc(t(out$p.theta.samples))
   
@@ -434,8 +403,6 @@ spLM <- function(formula, data = parent.frame(), coords, knots,
   out$nugget <- nugget
   out$beta.prior <- beta.prior
   out$beta.Norm <- beta.Norm
-  ## out$r.indx <- r.indx
-  ## out$get.beta <- get.beta
   out$x.names <- x.names
   out$run.time <- run.time
   
